from __future__ import annotations

# RDAP TLD registry — sourced from IANA bootstrap (https://data.iana.org/rdap/dns.json)
# Only includes TLDs registrable by the general public. Excludes xn-- (IDN) and brand-only TLDs.

RDAP_REGISTRY: dict[str, str] = {
    # --- Major gTLDs ---
    "com": "https://rdap.verisign.com/com/v1",
    "net": "https://rdap.verisign.com/net/v1",
    "org": "https://rdap.publicinterestregistry.org/rdap",
    "info": "https://rdap.identitydigital.services/rdap",
    "name": "https://tld-rdap.verisign.com/name/v1",
    "pro": "https://rdap.identitydigital.services/rdap",
    "mobi": "https://rdap.identitydigital.services/rdap",
    "tel": "https://rdap.nic.tel",
    "int": "https://rdap.iana.org",
    "cc": "https://tld-rdap.verisign.com/cc/v1",
    # --- ccTLDs with RDAP ---
    "ad": "https://rdap.nic.ad",
    "ai": "https://rdap.identitydigital.services/rdap",
    "ar": "https://rdap.nic.ar",
    "as": "https://rdap.nic.as",
    "au": "https://rdap.cctld.au/rdap",
    "bm": "https://rdap.identitydigital.services/rdap",
    "br": "https://rdap.registro.br",
    "ca": "https://rdap.ca.fury.ca/rdap",
    "ch": "https://rdap.nic.ch",
    "cr": "https://rdap.nic.cr",
    "cv": "https://rdap.nic.cv",
    "cx": "https://rdap.nic.cx",
    "cz": "https://rdap.nic.cz",
    "ec": "https://rdap.registry.ec",
    "fi": "https://rdap.fi/rdap/rdap",
    "fm": "https://rdap.centralnic.com/fm",
    "fo": "https://rdap.centralnic.com/fo",
    "fr": "https://rdap.nic.fr",
    "gd": "https://rdap.centralnic.com/gd",
    "gy": "https://rdap.registry.gy",
    "hn": "https://rdap.nic.hn",
    "ht": "https://rdap.nic.ht",
    "id": "https://rdap.pandi.id/rdap",
    "in": "https://rdap.nixiregistry.in/rdap",
    "is": "https://rdap.isnic.is/rdap",
    "ke": "https://rdap.kenic.or.ke",
    "kg": "http://rdap.cctld.kg",
    "ky": "https://whois.kyregistry.ky/rdap",
    "lb": "https://rdap.lbdr.org.lb",
    "ly": "https://rdap.nic.ly",
    "mg": "http://rdap.nic.mg",
    "ml": "https://rdap.nic.ml",
    "ms": "https://rdap.nic.ms",
    "mu": "https://rdap.identitydigital.services/rdap",
    "na": "https://keetmans.omadhina.co.na",
    "nf": "https://rdap.nic.nf",
    "nl": "https://rdap.sidn.nl",
    "no": "https://rdap.norid.no",
    "pg": "https://rdap.nic.pg",
    "pl": "https://rdap.dns.pl",
    "pm": "https://rdap.nic.pm",
    "pw": "https://rdap.centralnic.com/pw",
    "re": "https://rdap.nic.re",
    "rw": "https://rdap.ricta.org.rw",
    "sd": "https://rdap.nic.sd",
    "sg": "https://rdap.sgnic.sg/rdap",
    "si": "https://rdap.register.si",
    "sr": "https://whois.sr/rdap",
    "ss": "https://rdap.nic.ss",
    "tf": "https://rdap.nic.tf",
    "th": "https://rdap.thains.co.th",
    "to": "https://rdap.tonicregistry.to/rdap",
    "tw": "https://ccrdap.twnic.tw/tw",
    "tz": "https://whois.tznic.or.tz/rdap",
    "ua": "https://rdap.hostmaster.ua",
    "uk": "https://rdap.nominet.uk/uk",
    "uz": "https://rdap.cctld.uz",
    "vg": "https://rdap.centralnic.com/vg",
    "vi": "https://rdap.nic.vi",
    "wf": "https://rdap.nic.wf",
    "ye": "https://rdap.y.net.ye",
    "yt": "https://rdap.nic.yt",
    "zm": "https://rdap.nic.zm",
    # --- Generic gTLDs ---
    "aero": "https://rdap.identitydigital.services/rdap",
    "academy": "https://rdap.identitydigital.services/rdap",
    "accountants": "https://rdap.identitydigital.services/rdap",
    "actor": "https://rdap.identitydigital.services/rdap",
    "africa": "https://rdap.nic.africa/rdap",
    "agency": "https://rdap.identitydigital.services/rdap",
    "airforce": "https://rdap.identitydigital.services/rdap",
    "alsace": "https://rdap.nic.alsace",
    "amsterdam": "https://rdap.nic.amsterdam",
    "apartments": "https://rdap.identitydigital.services/rdap",
    "app": "https://pubapi.registry.google/rdap",
    "arab": "https://rdap.nic.arab",
    "archi": "https://rdap.identitydigital.services/rdap",
    "army": "https://rdap.identitydigital.services/rdap",
    "art": "https://rdap.centralnic.com/art",
    "asia": "https://rdap.identitydigital.services/rdap",
    "associates": "https://rdap.identitydigital.services/rdap",
    "attorney": "https://rdap.identitydigital.services/rdap",
    "auction": "https://rdap.identitydigital.services/rdap",
    "audio": "https://rdap.centralnic.com/audio",
    "auto": "https://rdap.centralnic.com/auto",
    "autos": "https://rdap.centralnic.com/autos",
    "baby": "https://rdap.centralnic.com/baby",
    "band": "https://rdap.identitydigital.services/rdap",
    "bar": "https://rdap.registry.bar/rdap",
    "barcelona": "https://rdap.nic.barcelona",
    "bargains": "https://rdap.identitydigital.services/rdap",
    "beauty": "https://rdap.centralnic.com/beauty",
    "beer": "https://rdap.nic.beer",
    "berlin": "https://rdap.nic.berlin/v1",
    "best": "https://rdap.centralnic.com/best",
    "bet": "https://rdap.identitydigital.services/rdap",
    "bike": "https://rdap.identitydigital.services/rdap",
    "bingo": "https://rdap.identitydigital.services/rdap",
    "bio": "https://rdap.identitydigital.services/rdap",
    "black": "https://rdap.identitydigital.services/rdap",
    "blog": "https://rdap.blog.fury.ca/rdap",
    "blue": "https://rdap.identitydigital.services/rdap",
    "boats": "https://rdap.centralnic.com/boats",
    "bond": "https://rdap.centralnic.com/bond",
    "boo": "https://pubapi.registry.google/rdap",
    "boutique": "https://rdap.identitydigital.services/rdap",
    "box": "https://rdap.centralnic.com/box",
    "broker": "https://rdap.identitydigital.services/rdap",
    "brussels": "https://rdap.nic.brussels",
    "build": "https://rdap.centralnic.com/build",
    "builders": "https://rdap.identitydigital.services/rdap",
    "business": "https://rdap.identitydigital.services/rdap",
    "bzh": "https://rdap.nic.bzh",
    "cab": "https://rdap.identitydigital.services/rdap",
    "cafe": "https://rdap.identitydigital.services/rdap",
    "cal": "https://pubapi.registry.google/rdap",
    "cam": "https://rdap.centralnic.com/cam",
    "camera": "https://rdap.identitydigital.services/rdap",
    "camp": "https://rdap.identitydigital.services/rdap",
    "capetown": "https://rdap.nic.capetown/rdap",
    "capital": "https://rdap.identitydigital.services/rdap",
    "car": "https://rdap.centralnic.com/car",
    "cards": "https://rdap.identitydigital.services/rdap",
    "care": "https://rdap.identitydigital.services/rdap",
    "career": "https://rdap.nominet.uk/career",
    "careers": "https://rdap.identitydigital.services/rdap",
    "cars": "https://rdap.centralnic.com/cars",
    "cash": "https://rdap.identitydigital.services/rdap",
    "casino": "https://rdap.identitydigital.services/rdap",
    "catering": "https://rdap.identitydigital.services/rdap",
    "center": "https://rdap.identitydigital.services/rdap",
    "ceo": "https://rdap.centralnic.com/ceo",
    "cfd": "https://rdap.centralnic.com/cfd",
    "channel": "https://pubapi.registry.google/rdap",
    "charity": "https://rdap.publicinterestregistry.org/rdap",
    "chat": "https://rdap.identitydigital.services/rdap",
    "cheap": "https://rdap.identitydigital.services/rdap",
    "christmas": "https://rdap.centralnic.com/christmas",
    "church": "https://rdap.identitydigital.services/rdap",
    "citic": "https://rdap.zdnsgtld.com/citic",
    "city": "https://rdap.identitydigital.services/rdap",
    "claims": "https://rdap.identitydigital.services/rdap",
    "cleaning": "https://rdap.identitydigital.services/rdap",
    "click": "https://rdap.tucowsregistry.net/rdap",
    "clinic": "https://rdap.identitydigital.services/rdap",
    "clothing": "https://rdap.identitydigital.services/rdap",
    "cloud": "https://rdap.registry.cloud/rdap",
    "coach": "https://rdap.identitydigital.services/rdap",
    "codes": "https://rdap.identitydigital.services/rdap",
    "coffee": "https://rdap.identitydigital.services/rdap",
    "college": "https://rdap.centralnic.com/college",
    "cologne": "https://rdap.ryce-rsp.com/rdap",
    "community": "https://rdap.identitydigital.services/rdap",
    "company": "https://rdap.identitydigital.services/rdap",
    "computer": "https://rdap.identitydigital.services/rdap",
    "condos": "https://rdap.identitydigital.services/rdap",
    "construction": "https://rdap.identitydigital.services/rdap",
    "consulting": "https://rdap.identitydigital.services/rdap",
    "contact": "https://rdap.identitydigital.services/rdap",
    "contractors": "https://rdap.identitydigital.services/rdap",
    "cool": "https://rdap.identitydigital.services/rdap",
    "coop": "https://rdap.registry.coop/rdap",
    "corsica": "https://rdap.nic.corsica",
    "country": "https://rdap.tucowsregistry.net/rdap",
    "coupon": "https://rdap.identitydigital.services/rdap",
    "coupons": "https://rdap.identitydigital.services/rdap",
    "credit": "https://rdap.identitydigital.services/rdap",
    "creditcard": "https://rdap.identitydigital.services/rdap",
    "creditunion": "https://rdap.registry.coop/rdap",
    "crown": "https://rdap.crown.fury.ca/rdap",
    "cruise": "https://rdap.identitydigital.services/rdap",
    "cruises": "https://rdap.identitydigital.services/rdap",
    "cymru": "https://rdap.nominet.uk/cymru",
    "cyou": "https://rdap.centralnic.com/cyou",
    "dad": "https://pubapi.registry.google/rdap",
    "dance": "https://rdap.identitydigital.services/rdap",
    "data": "https://rdap.mobile-registry.com/rdap",
    "dating": "https://rdap.identitydigital.services/rdap",
    "day": "https://pubapi.registry.google/rdap",
    "deals": "https://rdap.identitydigital.services/rdap",
    "degree": "https://rdap.identitydigital.services/rdap",
    "delivery": "https://rdap.identitydigital.services/rdap",
    "democrat": "https://rdap.identitydigital.services/rdap",
    "dental": "https://rdap.identitydigital.services/rdap",
    "dentist": "https://rdap.identitydigital.services/rdap",
    "design": "https://rdap.nic.design",
    "desi": "https://rdap.nominet.uk/desi",
    "dev": "https://pubapi.registry.google/rdap",
    "diamonds": "https://rdap.identitydigital.services/rdap",
    "digital": "https://rdap.identitydigital.services/rdap",
    "direct": "https://rdap.identitydigital.services/rdap",
    "directory": "https://rdap.identitydigital.services/rdap",
    "discount": "https://rdap.identitydigital.services/rdap",
    "diy": "https://rdap.tucowsregistry.net/rdap",
    "doctor": "https://rdap.identitydigital.services/rdap",
    "dog": "https://rdap.identitydigital.services/rdap",
    "domains": "https://rdap.identitydigital.services/rdap",
    "dubai": "https://rdap.nic.dubai",
    "durban": "https://rdap.nic.durban/rdap",
    "eat": "https://pubapi.registry.google/rdap",
    "eco": "https://rdap.eco.fury.ca/rdap",
    "education": "https://rdap.identitydigital.services/rdap",
    "email": "https://rdap.identitydigital.services/rdap",
    "energy": "https://rdap.identitydigital.services/rdap",
    "engineer": "https://rdap.identitydigital.services/rdap",
    "engineering": "https://rdap.identitydigital.services/rdap",
    "enterprises": "https://rdap.identitydigital.services/rdap",
    "equipment": "https://rdap.identitydigital.services/rdap",
    "esq": "https://pubapi.registry.google/rdap",
    "estate": "https://rdap.identitydigital.services/rdap",
    "events": "https://rdap.identitydigital.services/rdap",
    "exchange": "https://rdap.identitydigital.services/rdap",
    "expert": "https://rdap.identitydigital.services/rdap",
    "exposed": "https://rdap.identitydigital.services/rdap",
    "express": "https://rdap.identitydigital.services/rdap",
    "fail": "https://rdap.identitydigital.services/rdap",
    "family": "https://rdap.identitydigital.services/rdap",
    "fan": "https://rdap.identitydigital.services/rdap",
    "fans": "https://rdap.centralnic.com/fans",
    "farm": "https://rdap.identitydigital.services/rdap",
    "feedback": "https://rdap.registry.click/rdap",
    "finance": "https://rdap.identitydigital.services/rdap",
    "financial": "https://rdap.identitydigital.services/rdap",
    "fit": "https://rdap.nic.fit",
    "fish": "https://rdap.identitydigital.services/rdap",
    "fitness": "https://rdap.identitydigital.services/rdap",
    "flights": "https://rdap.identitydigital.services/rdap",
    "florist": "https://rdap.identitydigital.services/rdap",
    "flowers": "https://rdap.centralnic.com/flowers",
    "fly": "https://pubapi.registry.google/rdap",
    "foo": "https://pubapi.registry.google/rdap",
    "food": "https://rdap.tucowsregistry.net/rdap",
    "football": "https://rdap.identitydigital.services/rdap",
    "forex": "https://rdap.identitydigital.services/rdap",
    "forsale": "https://rdap.identitydigital.services/rdap",
    "forum": "https://rdap.registry.click/rdap",
    "foundation": "https://rdap.publicinterestregistry.org/rdap",
    "frl": "https://rdap.centralnic.com/frl",
    "fun": "https://rdap.centralnic.com/fun",
    "fund": "https://rdap.identitydigital.services/rdap",
    "furniture": "https://rdap.identitydigital.services/rdap",
    "futbol": "https://rdap.identitydigital.services/rdap",
    "fyi": "https://rdap.identitydigital.services/rdap",
    "gal": "https://rdap.nic.gal",
    "gallery": "https://rdap.identitydigital.services/rdap",
    "game": "https://rdap.centralnic.com/game",
    "games": "https://rdap.identitydigital.services/rdap",
    "gdn": "https://rdap.nic.gdn",
    "gent": "https://rdap.centralnic.com/gent",
    "gift": "https://rdap.tucowsregistry.net/rdap",
    "gifts": "https://rdap.identitydigital.services/rdap",
    "gives": "https://rdap.publicinterestregistry.org/rdap",
    "giving": "https://rdap.publicinterestregistry.org/rdap",
    "glass": "https://rdap.identitydigital.services/rdap",
    "global": "https://rdap.identitydigital.services/rdap",
    "gmbh": "https://rdap.identitydigital.services/rdap",
    "gold": "https://rdap.identitydigital.services/rdap",
    "golf": "https://rdap.identitydigital.services/rdap",
    "gov": "https://rdap.nic.gov/rdap",
    "graphics": "https://rdap.identitydigital.services/rdap",
    "gratis": "https://rdap.identitydigital.services/rdap",
    "green": "https://rdap.identitydigital.services/rdap",
    "gripe": "https://rdap.identitydigital.services/rdap",
    "group": "https://rdap.identitydigital.services/rdap",
    "guide": "https://rdap.identitydigital.services/rdap",
    "guitars": "https://rdap.centralnic.com/guitars",
    "guru": "https://rdap.identitydigital.services/rdap",
    "hair": "https://rdap.centralnic.com/hair",
    "hamburg": "https://rdap.nic.hamburg/v1",
    "haus": "https://rdap.identitydigital.services/rdap",
    "healthcare": "https://rdap.identitydigital.services/rdap",
    "help": "https://rdap.centralnic.com/help",
    "here": "https://pubapi.registry.google/rdap",
    "hiphop": "https://rdap.registry.hiphop/rdap",
    "hiv": "https://rdap.tucowsregistry.net/rdap",
    "hockey": "https://rdap.identitydigital.services/rdap",
    "holdings": "https://rdap.identitydigital.services/rdap",
    "holiday": "https://rdap.identitydigital.services/rdap",
    "horse": "https://rdap.nic.horse",
    "homes": "https://rdap.centralnic.com/homes",
    "hospital": "https://rdap.identitydigital.services/rdap",
    "host": "https://rdap.centralnic.com/host",
    "hosting": "https://rdap.centralnic.com/hosting",
    "house": "https://rdap.identitydigital.services/rdap",
    "how": "https://pubapi.registry.google/rdap",
    "icu": "https://rdap.centralnic.com/icu",
    "immo": "https://rdap.identitydigital.services/rdap",
    "immobilien": "https://rdap.identitydigital.services/rdap",
    "inc": "https://rdap.centralnic.com/inc",
    "industries": "https://rdap.identitydigital.services/rdap",
    "ing": "https://pubapi.registry.google/rdap",
    "institute": "https://rdap.identitydigital.services/rdap",
    "insure": "https://rdap.identitydigital.services/rdap",
    "international": "https://rdap.identitydigital.services/rdap",
    "investments": "https://rdap.identitydigital.services/rdap",
    "irish": "https://rdap.identitydigital.services/rdap",
    "jetzt": "https://rdap.identitydigital.services/rdap",
    "jewelry": "https://rdap.identitydigital.services/rdap",
    "jobs": "https://rdap.nominet.uk/jobs",
    "joburg": "https://rdap.nic.joburg/rdap",
    "kaufen": "https://rdap.identitydigital.services/rdap",
    "kids": "https://rdap.identitydigital.services/rdap",
    "kim": "https://rdap.identitydigital.services/rdap",
    "kitchen": "https://rdap.identitydigital.services/rdap",
    "kiwi": "https://rdap.kiwi.fury.ca/rdap",
    "koeln": "https://rdap.ryce-rsp.com/rdap",
    "kyoto": "https://rdap.gmoregistry.net/rdap",
    "land": "https://rdap.identitydigital.services/rdap",
    "lat": "https://rdap.centralnic.com/lat",
    "latino": "https://rdap.mobile-registry.com/rdap",
    "lawyer": "https://rdap.identitydigital.services/rdap",
    "lease": "https://rdap.identitydigital.services/rdap",
    "legal": "https://rdap.identitydigital.services/rdap",
    "lgbt": "https://rdap.identitydigital.services/rdap",
    "life": "https://rdap.identitydigital.services/rdap",
    "lifestyle": "https://rdap.tucowsregistry.net/rdap",
    "lighting": "https://rdap.identitydigital.services/rdap",
    "limited": "https://rdap.identitydigital.services/rdap",
    "limo": "https://rdap.identitydigital.services/rdap",
    "link": "https://rdap.tucowsregistry.net/rdap",
    "live": "https://rdap.identitydigital.services/rdap",
    "living": "https://rdap.tucowsregistry.net/rdap",
    "llc": "https://rdap.identitydigital.services/rdap",
    "loans": "https://rdap.identitydigital.services/rdap",
    "lol": "https://rdap.centralnic.com/lol",
    "london": "https://rdap.centralnic.com/london",
    "lotto": "https://rdap.identitydigital.services/rdap",
    "love": "https://rdap.registry.love/rdap",
    "ltd": "https://rdap.identitydigital.services/rdap",
    "ltda": "https://rdap.identitydigital.services/rdap",
    "luxury": "https://rdap.centralnic.com/luxury",
    "madrid": "https://rdap.nic.madrid",
    "maison": "https://rdap.identitydigital.services/rdap",
    "makeup": "https://rdap.centralnic.com/makeup",
    "management": "https://rdap.identitydigital.services/rdap",
    "map": "https://pubapi.registry.google/rdap",
    "market": "https://rdap.identitydigital.services/rdap",
    "marketing": "https://rdap.identitydigital.services/rdap",
    "markets": "https://rdap.identitydigital.services/rdap",
    "mba": "https://rdap.identitydigital.services/rdap",
    "media": "https://rdap.identitydigital.services/rdap",
    "meet": "https://pubapi.registry.google/rdap",
    "meme": "https://pubapi.registry.google/rdap",
    "memorial": "https://rdap.identitydigital.services/rdap",
    "mls": "https://rdap.mls.fury.ca/rdap",
    "mobile": "https://rdap.mobile-registry.com/rdap",
    "moda": "https://rdap.identitydigital.services/rdap",
    "mom": "https://rdap.centralnic.com/mom",
    "money": "https://rdap.identitydigital.services/rdap",
    "monster": "https://rdap.centralnic.com/monster",
    "mortgage": "https://rdap.identitydigital.services/rdap",
    "moscow": "https://rdap.flexireg.net",
    "motorcycles": "https://rdap.centralnic.com/motorcycles",
    "mov": "https://pubapi.registry.google/rdap",
    "movie": "https://rdap.identitydigital.services/rdap",
    "museum": "https://rdap.nic.museum",
    "music": "https://rdap.registryservices.music/rdap",
    "nagoya": "https://rdap.gmoregistry.net/rdap",
    "navy": "https://rdap.identitydigital.services/rdap",
    "network": "https://rdap.identitydigital.services/rdap",
    "new": "https://pubapi.registry.google/rdap",
    "news": "https://rdap.identitydigital.services/rdap",
    "nexus": "https://pubapi.registry.google/rdap",
    "ngo": "https://rdap.publicinterestregistry.org/rdap",
    "ninja": "https://rdap.identitydigital.services/rdap",
    "nrw": "https://rdap.nic.nrw",
    "observer": "https://rdap.registry.click/rdap",
    "okinawa": "https://rdap.gmoregistry.net/rdap",
    "ong": "https://rdap.publicinterestregistry.org/rdap",
    "onl": "https://rdap.identitydigital.services/rdap",
    "online": "https://rdap.centralnic.com/online",
    "ooo": "https://rdap.centralnic.com/ooo",
    "organic": "https://rdap.identitydigital.services/rdap",
    "ovh": "https://rdap.nic.ovh",
    "page": "https://pubapi.registry.google/rdap",
    "paris": "https://rdap.nic.paris",
    "partners": "https://rdap.identitydigital.services/rdap",
    "parts": "https://rdap.identitydigital.services/rdap",
    "pet": "https://rdap.identitydigital.services/rdap",
    "phd": "https://pubapi.registry.google/rdap",
    "phone": "https://rdap.mobile-registry.com/rdap",
    "photography": "https://rdap.identitydigital.services/rdap",
    "photos": "https://rdap.identitydigital.services/rdap",
    "pics": "https://rdap.centralnic.com/pics",
    "pictures": "https://rdap.identitydigital.services/rdap",
    "pink": "https://rdap.identitydigital.services/rdap",
    "pizza": "https://rdap.identitydigital.services/rdap",
    "place": "https://rdap.identitydigital.services/rdap",
    "play": "https://pubapi.registry.google/rdap",
    "plumbing": "https://rdap.identitydigital.services/rdap",
    "plus": "https://rdap.identitydigital.services/rdap",
    "poker": "https://rdap.identitydigital.services/rdap",
    "press": "https://rdap.centralnic.com/press",
    "prod": "https://pubapi.registry.google/rdap",
    "productions": "https://rdap.identitydigital.services/rdap",
    "prof": "https://pubapi.registry.google/rdap",
    "promo": "https://rdap.identitydigital.services/rdap",
    "properties": "https://rdap.identitydigital.services/rdap",
    "property": "https://rdap.tucowsregistry.net/rdap",
    "pub": "https://rdap.identitydigital.services/rdap",
    "qpon": "https://rdap.centralnic.com/qpon",
    "quebec": "https://rdap.nic.quebec",
    "quest": "https://rdap.centralnic.com/quest",
    "realty": "https://rdap.registry.click/rdap",
    "recipes": "https://rdap.identitydigital.services/rdap",
    "red": "https://rdap.identitydigital.services/rdap",
    "rehab": "https://rdap.identitydigital.services/rdap",
    "reise": "https://rdap.identitydigital.services/rdap",
    "reisen": "https://rdap.identitydigital.services/rdap",
    "ren": "https://rdap.zdnsgtld.com/ren",
    "rent": "https://rdap.centralnic.com/rent",
    "rentals": "https://rdap.identitydigital.services/rdap",
    "repair": "https://rdap.identitydigital.services/rdap",
    "report": "https://rdap.identitydigital.services/rdap",
    "republican": "https://rdap.identitydigital.services/rdap",
    "rest": "https://rdap.registry.bar/rdap",
    "restaurant": "https://rdap.identitydigital.services/rdap",
    "reviews": "https://rdap.identitydigital.services/rdap",
    "rio": "https://rdap.gtlds.nic.br",
    "rip": "https://rdap.identitydigital.services/rdap",
    "rocks": "https://rdap.identitydigital.services/rdap",
    "rsvp": "https://pubapi.registry.google/rdap",
    "ruhr": "https://rdap.centralnic.com/ruhr",
    "run": "https://rdap.identitydigital.services/rdap",
    "ryukyu": "https://rdap.gmoregistry.net/rdap",
    "sale": "https://rdap.identitydigital.services/rdap",
    "salon": "https://rdap.identitydigital.services/rdap",
    "sarl": "https://rdap.identitydigital.services/rdap",
    "sbs": "https://rdap.centralnic.com/sbs",
    "school": "https://rdap.identitydigital.services/rdap",
    "schule": "https://rdap.identitydigital.services/rdap",
    "search": "https://pubapi.registry.google/rdap",
    "services": "https://rdap.identitydigital.services/rdap",
    "sexy": "https://rdap.tucowsregistry.net/rdap",
    "shiksha": "https://rdap.identitydigital.services/rdap",
    "shoes": "https://rdap.identitydigital.services/rdap",
    "shop": "https://rdap.gmoregistry.net/rdap",
    "shopping": "https://rdap.identitydigital.services/rdap",
    "show": "https://rdap.identitydigital.services/rdap",
    "singles": "https://rdap.identitydigital.services/rdap",
    "site": "https://rdap.centralnic.com/site",
    "ski": "https://rdap.identitydigital.services/rdap",
    "skin": "https://rdap.centralnic.com/skin",
    "soccer": "https://rdap.identitydigital.services/rdap",
    "social": "https://rdap.identitydigital.services/rdap",
    "software": "https://rdap.identitydigital.services/rdap",
    "solar": "https://rdap.identitydigital.services/rdap",
    "solutions": "https://rdap.identitydigital.services/rdap",
    "soy": "https://pubapi.registry.google/rdap",
    "spa": "https://rdap.identitydigital.services/rdap",
    "space": "https://rdap.centralnic.com/space",
    "srl": "https://rdap.identitydigital.services/rdap",
    "storage": "https://rdap.centralnic.com/storage",
    "store": "https://rdap.centralnic.com/store",
    "studio": "https://rdap.identitydigital.services/rdap",
    "style": "https://rdap.identitydigital.services/rdap",
    "supplies": "https://rdap.identitydigital.services/rdap",
    "supply": "https://rdap.identitydigital.services/rdap",
    "support": "https://rdap.identitydigital.services/rdap",
    "surf": "https://rdap.nic.surf",
    "surgery": "https://rdap.identitydigital.services/rdap",
    "swiss": "https://rdap.nic.swiss",
    "systems": "https://rdap.identitydigital.services/rdap",
    "tatar": "https://whois.nic.tatar/rdap",
    "tattoo": "https://rdap.nic.tattoo",
    "tax": "https://rdap.identitydigital.services/rdap",
    "taxi": "https://rdap.identitydigital.services/rdap",
    "team": "https://rdap.identitydigital.services/rdap",
    "tech": "https://rdap.centralnic.com/tech",
    "technology": "https://rdap.identitydigital.services/rdap",
    "tennis": "https://rdap.identitydigital.services/rdap",
    "theater": "https://rdap.identitydigital.services/rdap",
    "theatre": "https://rdap.centralnic.com/theatre",
    "tickets": "https://rdap.centralnic.com/tickets",
    "tienda": "https://rdap.identitydigital.services/rdap",
    "tips": "https://rdap.identitydigital.services/rdap",
    "tires": "https://rdap.identitydigital.services/rdap",
    "tirol": "https://rdap.ryce-rsp.com/rdap",
    "today": "https://rdap.identitydigital.services/rdap",
    "tokyo": "https://rdap.gmoregistry.net/rdap",
    "tools": "https://rdap.identitydigital.services/rdap",
    "top": "https://rdap.zdnsgtld.com/top",
    "tours": "https://rdap.identitydigital.services/rdap",
    "town": "https://rdap.identitydigital.services/rdap",
    "toys": "https://rdap.identitydigital.services/rdap",
    "trading": "https://rdap.identitydigital.services/rdap",
    "training": "https://rdap.identitydigital.services/rdap",
    "travel": "https://rdap.identitydigital.services/rdap",
    "trust": "https://rdap.tucowsregistry.net/rdap",
    "tube": "https://rdap.nic.tube",
    "university": "https://rdap.identitydigital.services/rdap",
    "uno": "https://rdap.centralnic.com/uno",
    "vacations": "https://rdap.identitydigital.services/rdap",
    "vana": "https://rdap.tucowsregistry.net/rdap",
    "vegas": "https://rdap.identitydigital.services/rdap",
    "ventures": "https://rdap.identitydigital.services/rdap",
    "versicherung": "https://rdap.nic.versicherung/v1",
    "vet": "https://rdap.identitydigital.services/rdap",
    "viajes": "https://rdap.identitydigital.services/rdap",
    "video": "https://rdap.identitydigital.services/rdap",
    "villas": "https://rdap.identitydigital.services/rdap",
    "vin": "https://rdap.identitydigital.services/rdap",
    "vip": "https://rdap.nic.vip",
    "vision": "https://rdap.identitydigital.services/rdap",
    "vlaanderen": "https://rdap.nic.vlaanderen",
    "vote": "https://rdap.identitydigital.services/rdap",
    "voto": "https://rdap.identitydigital.services/rdap",
    "voyage": "https://rdap.identitydigital.services/rdap",
    "wales": "https://rdap.nominet.uk/wales",
    "wang": "https://rdap.zdnsgtld.com/wang",
    "watch": "https://rdap.identitydigital.services/rdap",
    "website": "https://rdap.centralnic.com/website",
    "wien": "https://rdap.ryce-rsp.com/rdap",
    "wine": "https://rdap.identitydigital.services/rdap",
    "works": "https://rdap.identitydigital.services/rdap",
    "world": "https://rdap.identitydigital.services/rdap",
    "wtf": "https://rdap.identitydigital.services/rdap",
    "xyz": "https://rdap.centralnic.com/xyz",
    "yachts": "https://rdap.centralnic.com/yachts",
    "yoga": "https://rdap.nic.yoga",
    "yokohama": "https://rdap.gmoregistry.net/rdap",
    "youtube": "https://pubapi.registry.google/rdap",
    "zip": "https://pubapi.registry.google/rdap",
    "zone": "https://rdap.identitydigital.services/rdap",
}
